@@ -27,11 +27,15 @@
 #' @section Example Output:
 #' \if{html}{Example 1}
 #'
-#' \if{html}{\figure{sort_filter_p_ex1.png}{options: width=50\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "sort_filter_p_ex1.png", width = "50")`
+#' }}
 #'
 #' \if{html}{Example 2}
 #'
-#' \if{html}{\figure{sort_p_ex2.png}{options: width=50\%}}
+#' \if{html}{\out{
+#' `r man_create_image_tag(file = "sort_p_ex2.png", width = "50")`
+#' }}
 NULL
 
 
@@ -67,7 +71,7 @@ sort_p <- function(x, q = FALSE) {
     group_by(.data$variable) %>%
     mutate(sort_col = min(.data[[sort_var]], na.rm = TRUE)) %>%
     arrange(.data$sort_col) %>%
-    select(-.data$sort_col) %>%
+    select(-"sort_col") %>%
     ungroup()
 
   # returning results ----------------------------------------------------------
@@ -106,7 +110,7 @@ filter_p <- function(x, q = FALSE, t = 0.05) {
     group_by(.data$variable) %>%
     mutate(sort_col = min(.data[[sort_var]], na.rm = TRUE)) %>%
     filter(.data$sort_col <= .env$t) %>%
-    select(-.data$sort_col) %>%
+    select(-"sort_col") %>%
     ungroup()
 
   # returning results ----------------------------------------------------------
