@@ -285,7 +285,7 @@ tbl_custom_summary <- function(data, by = NULL, label = NULL,
   if (!is.null(by) && sum(is.na(data[[by]])) > 0) {
     message(glue(
       "{sum(is.na(data[[by]]))} observations missing `{by}` have been removed. ",
-      "To include these observations, use `forcats::fct_explicit_na()` on `{by}` ",
+      "To include these observations, use `forcats::fct_na_value_to_level()` on `{by}` ",
       "column before passing to `tbl_summary()`."
     ))
 
@@ -630,13 +630,12 @@ summarize_custom <- function(data, stat_fn, variable, by, stat_display,
   # adding stat_display to the data frame
   if (summary_type == "continuous2") {
     return <-
-      left_join(
+      dplyr::cross_join(
         df_stats,
         tibble(
           variable_levels = map_chr(stat_display, ~ stat_label_match(.x) %>% unlist()),
           stat_display = stat_display
-        ),
-        by = character()
+        )
       ) %>%
       select(any_of(c("by", "variable", "variable_levels", "stat_display")), everything())
   } else {
