@@ -157,7 +157,7 @@ tidy_prep <- function(x, tidy_fun, exponentiate, conf.level, intercept, label,
       columns = any_of("std.error"),
       label = paste0("**", translate_text("SE"), "**"),
       footnote_abbrev = translate_text("SE = Standard Error"),
-      fmt_fun = purrr::partial(style_sigfig, digits = 3),
+      fmt_fun = function(x) style_sigfig(x, digits = 3),
       hide = !"std.error" %in% tidy_columns_to_report
     ) %>%
     modify_table_styling(
@@ -172,7 +172,7 @@ tidy_prep <- function(x, tidy_fun, exponentiate, conf.level, intercept, label,
       x,
       columns = any_of("statistic"),
       label = paste0("**", translate_text("Statistic"), "**"),
-      fmt_fun = purrr::partial(style_sigfig, digits = 3),
+      fmt_fun = function(x) style_sigfig(x, digits = 3),
       hide = !"statistic" %in% tidy_columns_to_report
     ) %>%
     modify_table_styling(
@@ -193,7 +193,7 @@ tidy_prep <- function(x, tidy_fun, exponentiate, conf.level, intercept, label,
             "N", "N_obs", "N_event", "n_obs", "n_event"
           ))
         ),
-      fmt_fun = purrr::partial(style_sigfig, digits = 3)
+      fmt_fun = function(x) style_sigfig(x, digits = 3)
     )
 
   x
