@@ -4,17 +4,17 @@ t1 <- trial %>% tbl_summary()
 t2 <- trial %>% tbl_summary(by = trt)
 test_that("no errors/warnings with standard use", {
   expect_error(res <- t1 %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_error(res <- t2 %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_warning(t1 %>% add_n(), NA)
   expect_warning(t2 %>% add_n(), NA)
 
   expect_error(res <- t1 %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_error(res <- t2 %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t1 %>% add_n(last = TRUE), NA)
   expect_warning(t2 %>% add_n(last = TRUE), NA)
 
@@ -27,7 +27,7 @@ test_that("no errors/warnings with standard use", {
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_error(
     t2 %>%
       add_n(
@@ -36,7 +36,7 @@ test_that("no errors/warnings with standard use", {
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t1 %>% add_n(
     statistic = "{N}{n}{n_miss}{p}{p_miss}",
     footnote = TRUE
@@ -59,16 +59,16 @@ t1 <- trial %>% tbl_summary(type = all_continuous() ~ "continuous2")
 t2 <- trial %>% tbl_summary(by = trt, type = all_continuous() ~ "continuous2")
 test_that("no errors/warnings with standard use with continuous2", {
   expect_error(res <- t1 %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_error(res <- t2 %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t1 %>% add_n(), NA)
   expect_warning(t2 %>% add_n(), NA)
 
   expect_error(res <- t1 %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_error(res <- t2 %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t1 %>% add_n(last = TRUE), NA)
   expect_warning(t2 %>% add_n(last = TRUE), NA)
 
@@ -80,7 +80,7 @@ test_that("no errors/warnings with standard use with continuous2", {
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(
     res <- t2 %>%
@@ -90,7 +90,7 @@ test_that("no errors/warnings with standard use with continuous2", {
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_warning(t1 %>% add_n(
     statistic = "{N}{n}{n_miss}{p}{p_miss}",
@@ -136,11 +136,11 @@ test_that("no errors/warnings with standard use for tbl_svysummary", {
     tbl_svysummary(by = trt)
 
   expect_error(res <- t %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(), NA)
 
   expect_error(res <- t %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(last = TRUE), NA)
 
   t <- Titanic %>%
@@ -157,7 +157,7 @@ test_that("no errors/warnings with standard use for tbl_svysummary", {
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(
     statistic = "{N}{n}{n_miss}{p}{p_miss}",
     footnote = TRUE
@@ -172,11 +172,11 @@ test_that("no errors/warnings with standard use for tbl_svysummary with continuo
     tbl_svysummary(by = trt, type = all_continuous() ~ "continuous2")
 
   expect_error(res <- t %>% add_n(), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(), NA)
 
   expect_error(res <- t %>% add_n(last = TRUE), NA)
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(last = TRUE), NA)
 
   t <- Titanic %>%
@@ -192,7 +192,7 @@ test_that("no errors/warnings with standard use for tbl_svysummary with continuo
       ),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
   expect_warning(t %>% add_n(
     statistic = "{N}{n}{n_miss}{p}{p_miss}",
     footnote = TRUE
@@ -200,9 +200,9 @@ test_that("no errors/warnings with standard use for tbl_svysummary with continuo
 })
 
 
-# add_n.tbl_surfit --------------------------------------------------------
+# add_n.tbl_survfit --------------------------------------------------------
 
-test_that("add_n.tbl_surfit", {
+test_that("add_n.tbl_survfit", {
   skip_if_not(broom.helpers::.assert_package("survival", pkg_search = "gtsummary", boolean = TRUE))
 
   tbl_survfit <-
@@ -216,7 +216,7 @@ test_that("add_n.tbl_surfit", {
     res <- add_n(tbl_survfit),
     NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 
@@ -229,17 +229,17 @@ test_that("add_n.tbl_regression", {
   expect_error(
     res <- tbl %>% add_n(), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(
     res <- tbl %>% add_n(location = "level"), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(
     res <- tbl %>% add_n(location = c("label", "level")), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
 
 # add_n.tbl_uvregression ---------------------------------------------------------
@@ -256,15 +256,15 @@ test_that("add_n.tbl_regression", {
   expect_error(
     res <- tbl %>% add_n(), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(
     res <- tbl %>% add_n(location = "level"), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 
   expect_error(
     res <- tbl %>% add_n(location = c("label", "level")), NA
   )
-  expect_snapshot(res %>% render_as_html())
+  expect_snapshot(res %>% as.data.frame())
 })
