@@ -515,3 +515,21 @@ test_that("add_p can be run after add_difference()", {
       rlang::is_empty()
   )
 })
+
+test_that("addressing GH #1513, where the default test was incorrect", {
+  expect_equal(
+    # before the fix, this was defaulting to a chi-sqaured, when it should be fisher
+    tibble::tibble(type = character(), answer = character()) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "A", answer = "C1"), 5)) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "B", answer = "C1"), 10)) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "A", answer = "C2"), 100)) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "B", answer = "C2"), 305)) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "A", answer = NA), 400)) %>%
+      tibble::add_row(tidyr::uncount(tibble::tibble(type = "B", answer = NA), 300)) %>%
+      .assign_test_tbl_summary(
+        variable = "answer", summary_type = "categorical", by = "type",
+        group = NULL, test = NULL
+      ),
+    "fisher.test"
+  )
+})
